==> currents-api-types-0.0.31.tgz: package/collective/parsers.ts <==
import { Collective, CollectiveAdminsTrait } from './types';
import { z, ZodType } from 'zod';
import { Subset } from '../utils/types';

import { channelListParamsParser } from '../channel/parsers';
import { nullableBoolParser, nullableStringParser, nullableUrlStringParser } from '../common/parsers';

import { stripeProductIdParser } from '../stripe/parsers';
import { isCollectiveId } from './id.utils';
import { firebaseBlogIdParser } from '../blog/parsers.id';
import { firebaseCollectiveIdParser } from './parsers.id';
import { firebaseUserIdParser } from '../auth/user/parsers.id';

export const collectiveBeneficiaryTraitParser = z.object({
  admins: z.array(firebaseBlogIdParser),
});

export const collectiveListQueryParser = channelListParamsParser;

export const collectiveListResultParser = z.array(z.any(/*stub*/)).transform((a) => a as Collective[]);

export const collectiveIdParser = z.string().refine(isCollectiveId);

export const collectiveGetOneParamsParser = z.object({
  id: collectiveIdParser,
});
export const collectiveGetOneResultParser = z.any(/*stub, not schemable*/).transform((b) => b as Collective);
export const collectiveDeleteParamsParser = collectiveGetOneParamsParser;

export const collectiveAdminParser = z.string(collectiveIdParser);

export const makeCollectiveAdminsTraitParser = <T1, T extends ZodType<T1>>(a: T) =>
  z.object({
    admins: a,
  });
export const makeCollectiveAdminsParser = <T extends string, P extends z.ZodType<T>>(p: P) => z.array(p);

export const collectiveAdminParserAdminsTraitParser = makeCollectiveAdminsTraitParser(
  makeCollectiveAdminsParser(collectiveAdminParser)
);

// eslint-disable-next-line
type AssertCollectiveBeneficiaryTraitParser1 = Subset<
  z.infer<typeof collectiveBeneficiaryTraitParser>,
  CollectiveAdminsTrait
>;
// eslint-disable-next-line
type AssertCollectiveBeneficiaryTraitParser2 = Subset<
  CollectiveAdminsTrait,
  z.infer<typeof collectiveBeneficiaryTraitParser>
>;
export const collectiveCreateInputParser = z
  .object({
    alias: nullableStringParser,
    blogs: z.array(firebaseBlogIdParser).default([]),
    collectiveSupport: nullableBoolParser,
    common: nullableBoolParser,
    commonBlogs: z.array(firebaseBlogIdParser).default([]),
    description: nullableStringParser,
    gofa: nullableBoolParser,
    hq: nullableStringParser,
    image: nullableUrlStringParser,
    launched: z.boolean().default(false),
    location: nullableStringParser,
    mv: nullableStringParser,
    MV: nullableStringParser,
    name: z.string(),
    planetFlyer: nullableStringParser,
    planetImage: nullableStringParser,
    planetName: nullableStringParser,
    planetPosition: z.record(z.number().nullable()).default({}),
    price: z.number().nullable(),
    radio: nullableBoolParser,
    smallImage: nullableUrlStringParser,
    sourceCollective: firebaseCollectiveIdParser,
    stripeProductID: stripeProductIdParser,
    subscribers: z.array(firebaseUserIdParser).default([]),
    type: nullableStringParser,
    updatedBy: z.string(firebaseUserIdParser),
    verified: z.boolean().default(false),
  })
  .merge(collectiveBeneficiaryTraitParser);
export const collectiveCreateOutputParser = collectiveIdParser;
export type CreateCollectiveRequest = z.infer<typeof collectiveCreateInputParser>;
export type CreateCollectiveResponse = z.infer<typeof collectiveCreateOutputParser>;

export const collectiveUpdateInputParser = collectiveCreateInputParser.partial();
export const collectiveUpdateParamsParser = collectiveGetOneParamsParser;
export const collectiveUpdateResultParser = z.void();

==> currents-api-types-0.0.33.tgz: package/collective/parsers.ts <==
import { Collective, CollectiveAdminsTrait } from './types';
import { z, ZodType } from 'zod';
import { cast, Subset } from '../utils/types';

import { channelListParamsParser } from '../channel/parsers';
import { nullableBoolParser, nullableStringParser, nullableUrlStringParser } from '../common/parsers';

import { stripeProductIdParser } from '../stripe/parsers';
import { isCollectiveId } from './id.utils';
import { firebaseBlogIdParser } from '../blog/parsers.id';
import { firebaseCollectiveIdParser } from './parsers.id';
import { firebaseUserIdParser } from '../auth/user/parsers.id';

export const collectiveBeneficiaryTraitParser = z.object({
  admins: z.array(firebaseBlogIdParser),
});

export const collectiveListQueryParser = channelListParamsParser;

export const collectiveListResultParser = z.array(z.any(/*stub*/)).transform(cast<Collective[]>());

export const collectiveIdParser = z.string().refine(isCollectiveId);

export const collectiveGetOneParamsParser = z.object({
  id: collectiveIdParser,
});
export const collectiveGetOneResultParser = z.any(/*stub, not schemable*/).transform((b) => b as Collective);
export const collectiveDeleteParamsParser = collectiveGetOneParamsParser;

export const collectiveAdminParser = z.string(collectiveIdParser);

export const makeCollectiveAdminsTraitParser = <T1, T extends ZodType<T1>>(a: T) =>
  z.object({
    admins: a,
  });
export const makeCollectiveAdminsParser = <T extends string, P extends z.ZodType<T>>(p: P) => z.array(p);

export const collectiveAdminParserAdminsTraitParser = makeCollectiveAdminsTraitParser(
  makeCollectiveAdminsParser(collectiveAdminParser)
);

// eslint-disable-next-line
type AssertCollectiveBeneficiaryTraitParser1 = Subset<
  z.infer<typeof collectiveBeneficiaryTraitParser>,
  CollectiveAdminsTrait
>;
// eslint-disable-next-line
type AssertCollectiveBeneficiaryTraitParser2 = Subset<
  CollectiveAdminsTrait,
  z.infer<typeof collectiveBeneficiaryTraitParser>
>;
export const collectiveCreateInputParser = z
  .object({
    alias: nullableStringParser,
    blogs: z.array(firebaseBlogIdParser).default([]),
    collectiveSupport: nullableBoolParser,
    common: nullableBoolParser,
    commonBlogs: z.array(firebaseBlogIdParser).default([]),
    description: nullableStringParser,
    gofa: nullableBoolParser,
    hq: nullableStringParser,
    image: nullableUrlStringParser,
    launched: z.boolean().default(false),
    location: nullableStringParser,
    mv: nullableStringParser,
    MV: nullableStringParser,
    name: z.string(),
    planetFlyer: nullableStringParser,
    planetImage: nullableStringParser,
    planetName: nullableStringParser,
    planetPosition: z.record(z.number().nullable()).default({}),
    price: z.number().nullable(),
    radio: nullableBoolParser,
    smallImage: nullableUrlStringParser,
    sourceCollective: firebaseCollectiveIdParser,
    stripeProductID: stripeProductIdParser,
    subscribers: z.array(firebaseUserIdParser).default([]),
    type: nullableStringParser,
    updatedBy: z.string(firebaseUserIdParser),
    verified: z.boolean().default(false),
  })
  .merge(collectiveBeneficiaryTraitParser);
export const collectiveCreateOutputParser = collectiveIdParser;
export type CreateCollectiveRequest = z.infer<typeof collectiveCreateInputParser>;
export type CreateCollectiveResponse = z.infer<typeof collectiveCreateOutputParser>;

export const collectiveUpdateInputParser = collectiveCreateInputParser.partial();
export const collectiveUpdateParamsParser = collectiveGetOneParamsParser;
export const collectiveUpdateResultParser = z.void();
